# Cameras CLI

## Usage
```
pip install cameras_cli
cameras register-realm http[s]://<core_cameras_host> <network_interface>
```

## Development
```
pip install --editable .
```

And then run the command as the usage part explains

## Deployment
1. Update the version number in the setup.py
2. 
```
pip install -U twine setuptools wheel
./setup.py sdist bdist_wheel
twine upload dist/*
```